# Scripts

Each individual file in this folder is a script, aimed to capture a command
for the project.

Because Makefiles have bitten the author once too much.

See [CONTRIBUTING.rst](../CONTRIBUTING.rst) for more details.
